# Mysodexo Python client

[![Build Status](https://travis-ci.com/AndreMiras/mysodexo.svg?branch=develop)](https://travis-ci.com/AndreMiras/mysodexo)
[![Coverage Status](https://coveralls.io/repos/github/AndreMiras/mysodexo/badge.svg?branch=develop)](https://coveralls.io/github/AndreMiras/mysodexo?branch=develop)
[![PyPI version](https://badge.fury.io/py/mysodexo.svg)](https://badge.fury.io/py/mysodexo)

Mysodexo Python client


## Usage

TODO
